#!/usr/bin/perl

# In the sample code, the ChartDirector for Perl module is assumed to be in "../lib"
use File::Basename;
use lib (dirname($0)."/../lib") =~ /(.*)/;

use perlchartdir;

# Sample data for the Box-Whisker chart. Represents the minimum, 1st quartile, medium, 3rd quartile
# and maximum values of some quantities
my $Q0Data = [40, 45, 40, 30, 20, 50, 25, 44];
my $Q1Data = [55, 60, 50, 40, 38, 60, 51, 60];
my $Q2Data = [62, 70, 60, 50, 48, 70, 62, 70];
my $Q3Data = [70, 80, 65, 60, 53, 78, 69, 76];
my $Q4Data = [80, 90, 75, 70, 60, 85, 80, 84];

# The labels for the chart
my $labels = ["A", "B", "C", "D", "E", "F", "G", "H"];

# Create a XYChart object of size 450 x 400 pixels
my $c = new XYChart(450, 400);

# Set the plotarea at (50, 30) and of size 380 x 340 pixels, with transparent background and border
# and light grey (0xcccccc) horizontal grid lines
$c->setPlotArea(50, 30, 380, 340, $perlchartdir::Transparent, -1, $perlchartdir::Transparent,
    0xcccccc);

# Add a title box using grey (0x555555) 18pt Arial font
my $title = $c->addTitle("     Pattern Recognition Accuracy", "arial.ttf", 18, 0x555555);

# Set the x and y axis stems to transparent and the label font to 12pt Arial
$c->xAxis()->setColors($perlchartdir::Transparent);
$c->yAxis()->setColors($perlchartdir::Transparent);
$c->xAxis()->setLabelStyle("arial.ttf", 12);
$c->yAxis()->setLabelStyle("arial.ttf", 12);

# Set the labels on the x axis
$c->xAxis()->setLabels($labels);

# For the automatic y-axis labels, set the minimum spacing to 30 pixels.
$c->yAxis()->setTickDensity(30);

# Add a box whisker layer using light blue (0x99ccee) for the fill color and blue (0x6688aa) for the
# whisker color. Set line width to 2 pixels. Use rounded corners and bar lighting effect.
my $b = $c->addBoxWhiskerLayer($Q3Data, $Q1Data, $Q4Data, $Q0Data, $Q2Data, 0x99ccee, 0x6688aa);
$b->setLineWidth(2);
$b->setRoundedCorners();
$b->setBorderColor($perlchartdir::Transparent, perlchartdir::barLighting());

# Adjust the plot area to fit under the title with 10-pixel margin on the other three sides.
$c->packPlotArea(10, $title->getHeight(), $c->getWidth() - 10, $c->getHeight() - 10);

# Output the chart
$c->makeChart("boxwhisker2.png")

